@@ -174,7 +174,7 @@ def client_side_proxy_wrapper(cmd,
             dict_file = {'server': {'httpPort': int(client_proxy_port), 'httpsPort': int(
                 api_server_port)}, 'identity': {'tenantID': tenantId, 'clientID': account['user']['name']}}
 
-        if cloud == 'DOGFOOD':
+        if 'DOGFOOD' in cloud:
             dict_file['cloud'] = 'AzureDogFood'
 
         if not is_cli_using_msal_auth():
